@@ -275,7 +275,7 @@ class Strategy:
         ret_all = ret_all + commission_all
         ret_all = np.exp(np.log1p(ret_all).cumsum())
         # ======================
-        ret_all = ret_all[ret_all.index.hour != 12]
+        ret_all = ret_all[ret_all.index.second == 0]
         return ret_all, hold_last
 
     @staticmethod
@@ -310,9 +310,9 @@ class Strategy:
         if self.matching_type == 'next_bar':
             trades_dt -= Commons.SHIFT_TIME
         trades_dt = trades_dt[trades_dt <= self.end_dt]
-        long_adjust_factor = (long_ret.loc[trades_dt].reindex(
+        long_adjust_factor = (long_ret.reindex(trades_dt).reindex(
             long_ret.index)).ffill().fillna(1)
-        short_adjust_factor = (short_ret.loc[trades_dt].reindex(
+        short_adjust_factor = (short_ret.reindex(trades_dt).reindex(
             short_ret.index)).ffill().fillna(1)
         # 对每期初始资金作调整，此时净值有跳跃
         long_adjust = long_ret / long_adjust_factor
@@ -343,8 +343,17 @@ class Strategy:
         assert (set(self._signal['asset'].columns)
                 | set(self._signal['future'])).issubset(
                     self._open.columns), 'Please check data stock range!'
-
         # 对信号进行修正
+        if self.matching_type == 'next_bar':
+            self._signal['asset'] = self._signal['asset'].reindex(
+                self._open.index).dropna(how='all')
+            self._signal['future'] = self._signal['future'].reindex(
+                self._open.index).dropna(how='all')
+        else:
+            self._signal['asset'] = self._signal['asset'].reindex(
+                self._close.index).dropna(how='all')
+            self._signal['future'] = self._signal['future'].reindex(
+                self._close.index).dropna(how='all')
         self._signal['asset'] = self._signal['asset'].loc[self.begin_dt:self.
                                                           end_dt].copy()
         self._signal['future'] = self._signal['future'].loc[self.begin_dt:self.
